# SiMDA - Size, Mass and Density of Asteroids
This catalog (data set) contains 'best' values for the bulk density, the size (volume-equivalent diameter) and the mass of 428 small bodies (mainly asteroids) of our Solar System.

4094 individual diameter estimates and 1760 individual mass estimates from the literature were used to find per object average values for these properties and from that for the bulk density. The data are complemented by dynamical (orbital) class and, if available, by taxonomic classes. The averages were computed using the 'Expected Value Method (EVM)' (Birch & Singh 2014).


## SiMDA online
SiMDA catalog is not only the data set presented here, but also an online system which provides the complete individual data, including their references and offers also some limited visualization and data processing capabilities. SiMDA can be accessed here: <https://astro.kretlow.de/simda>


## Cite
You can either cite this specific data set (using the Zenodo DOI) and / or acknowledge the SiMDA project in general:

Kretlow, M., 2020: Size, Mass and Density of Asteroids (SiMDA) - A Web Based Archive and Data Service. EPSC Abstracts Vol. 14, EPSC2020-690. <a href="https://meetingorganizer.copernicus.org/EPSC2020/EPSC2020-690.html">URL</a>


## References
M. Birch, B. Singh. Method of Best Representation for Averages in Data Evaluation. Nucl. Data Sheets 120, 106 (2014). <a href="https://doi.org/10.1016/j.nds.2014.07.019">DOI</a>  
Carry, B., 2012 : Density of asteroids. Planetary and Space Science, Volume 73, Issue 1, p. 98-118. <a href="https://ui.adsabs.harvard.edu/abs/2012P%26SS...73...98C/abstract">ADS</a>


## Changelog
v1.0 (20-09-15): Initial release  
v1.1 (20-09-20): Spacecraft derived data for Ceres, Vesta, Bennu and Ryugu added. Plus some minor changes.  


## Notes & Issues
81P/Wild 2 : The density value 0.7 ± 0.10 g / cm^3 from indirect measurement (from non-gravitational forces) should be preferred. See SiMDA website.  


## The data
The data set is provided as CSV and as JSON file. The data fields are:

| Column / Field | Description |
|:---------------|:------------|
| NUM | Number of the asteroid |
| DESIGNATION | Name or provisional designation of the object |
| DYN | Orbital class: COM = Comet, MBA = Main-Belt Asteroid (IMB, OMB, MCA), NEA = Near Earth Asteroid, CEN = Centaur, TNO = Trans-Neptunian Object. See <a href="https://pdssbn.astro.umd.edu/data_other/objclass.shtml">here</a> |
| BD | Bulk density in g / cm^3, calculated from DIAM and MASS |
| BD.E | Absolute error of BD |
| BD.R | Relative error of BD in % |
| RNK | Bulk density accuracy rank (A to E, plus X = unrealisitc) |
| DIAM | Volume-equivalent diameter D in km |
| DIAM.E | Absolute error of D in km |
| DIAM.R | Relative error of D in % |
| MASS | Mass M in kg|
| MASS.E | Absolute error of M in kg |
| MASS.R | Relative error of M in % |
| T.T | Tholen Tax Class |
| T.B | Bus & Binzel Tax Class |
| L.T | S3OS2 Lazarro (Tholen) Tax Class |
| L.B | S3OS2 Lazarro (Bus & Binzel) Tax Class |
| T.D | DeMeo Tax Class |
| C_TAX | Tax Class as given in Carry (2012)|
| C_BD | Bulk density in g / cm^3 as given Carry (2012) |
| C_BD.E | Absolute error of C_BD |
| C_BD.R | Relative error of C_BD in %|
| C_RNK | Bulk density accuracy rank (A to E, plus X = unrealisitc) as given in Carry (2012)|


**Bulk density accuracy ranking:** (A) to (E), corresponding to the relative error: (B) less than 20%, (C) between 20 and 50%, (D) between 50 and 100%, and (E) more than 100%. (A) stands for (presumably) reliable estimates (accuracy better than 20%), based on more than 5 mass estimates and 5 diameter estimates, or a spacecraft encounter. Apparently unrealistic densities (BD &lt; 0.1 or BD &gt; 8) are tagged with (X).


